AGW Logo

svn SVN Revision 69719 For aquabutton

This file contains the SVN revision history for aquabutton, at revision 69719.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 20:51:43 UTC
  • Committer: AG
  • File Size: 29743 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

AquaButton: changed the default height for the button to 24 pixels when the button itself does not have a bitmap.


svn_diff Diff To Previous Version (69134)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/aquabutton.py 2011/09/17 22:02:20     69134
+++ wxPython/3rdParty/AGW/agw/aquabutton.py 2011/11/09 21:31:32     69719
@@ -2,7 +2,7 @@
# AQUABUTTON wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 17 Sep 2011, 23.00 GMT
#
#
# TODO List
@@ -100,7 +100,7 @@

L{AquaButton} control is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 17 Sep 2011, 17.00 GMT
+Latest Revision: Andrea Gavana @ 09 Nov 2011, 21.00 GMT

Version 0.4

@@ -657,7 +657,7 @@
retWidth, retHeight = dc.GetTextExtent(label)

bmpWidth = bmpHeight = 0
-        constant = 30
+        constant = 24
if self._bitmap:
bmpWidth, bmpHeight = self._bitmap.GetWidth()+10, self._bitmap.GetHeight()
retWidth += bmpWidth
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 17 Sep 2011, 23.00 GMT
+# Latest Revision: 09 Nov 2011, 21.00 GMT
#
#
Tree